.. EmbyPy documentation master file, created by
   sphinx-quickstart on Thu Sep 28 17:16:54 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

EmbyPy's documentation!
==================================
Start with the :class:`embypy.Emby` class, it should be the main thing that your
make requests to.

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   embypy
   embypy.objects
   embypy.utils

   license


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
